==> miro_2.0.3.orig.tar.gz: miro-2.0.3.orig/portable/frontends/shell/application.py <==
# Miro - an RSS based video player application
# Copyright (C) 2005-2009 Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.

"""miro.portable.frontends.shell -- A quick shell for debugging Miro
innards.
"""

import readline
import rlcompleter
import code
import threading

from miro import app
from miro import startup
from miro import messages

def run_application(props_to_set):
    # FIXME - ignoring props_to_set
    messages.FrontendMessage.install_handler(MessageHandler())
    startup.startup()
    print 'startup exit'

class MessageHandler(messages.MessageHandler):
    def handle(self, message):
        if isinstance(message, messages.StartupSuccess):
            self.run_shell()
        else:
            print 'got message: ', message

    def run_shell(self):
        print
        print '** starting shell**'
        print
        imported_objects = {}
        for mod in ('database', 'feed', 'item', 'views'):
            imported_objects[mod] = getattr(__import__('miro.%s' % mod), mod)
        readline.set_completer(rlcompleter.Completer(imported_objects).complete)
        readline.parse_and_bind("tab:complete")
        code.interact(local=imported_objects)

        app.controller.shutdown()

==> miro_2.5.3.orig.tar.gz: miro-2.5.3.orig/portable/frontends/shell/application.py <==
# Miro - an RSS based video player application
# Copyright (C) 2005-2009 Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.

"""miro.portable.frontends.shell -- A quick shell for debugging Miro
innards.
"""

import readline
import rlcompleter
import code
import threading

from miro import app
from miro import startup
from miro import messages

def run_application(props_to_set):
    # FIXME - ignoring props_to_set
    messages.FrontendMessage.install_handler(MessageHandler())
    startup.startup()
    print 'startup exit'

class MessageHandler(messages.MessageHandler):
    def handle(self, message):
        if isinstance(message, messages.StartupSuccess):
            self.run_shell()
        else:
            print 'got message: ', message

    def run_shell(self):
        print
        print '** starting shell**'
        print
        imported_objects = {}
        for mod in ('database', 'feed', 'item', 'models'):
            imported_objects[mod] = getattr(__import__('miro.%s' % mod), mod)
        readline.set_completer(rlcompleter.Completer(imported_objects).complete)
        readline.parse_and_bind("tab:complete")
        code.interact(local=imported_objects)

        app.controller.shutdown()
